@@ -71,6 +71,20 @@ char *strncpy(char *dest, const char *src, size_t n) __THROW;
 #include	"md_p.h"
 #include	"bitmap.h"
 
+#include <endian.h>
+/* #include "asm/byteorder.h" Redhat don't like this so... */
+#if __BYTE_ORDER == __LITTLE_ENDIAN
+#  include <linux/byteorder/little_endian.h>
+#elif __BYTE_ORDER == __BIG_ENDIAN
+#  include <linux/byteorder/big_endian.h>
+#elif __BYTE_ORDER == __PDP_ENDIAN
+#  include <linux/byteorder/pdp_endian.h>
+#else
+#  error "unknown endianness."
+#endif
+
+
+
 /* general information that might be extracted from a superblock */
 struct mdinfo {
 	mdu_array_info_t	array;
@@ -160,7 +174,7 @@ struct mdstat_ent {
 	struct mdstat_ent *next;
 };
 
-extern struct mdstat_ent *mdstat_read(int);
+extern struct mdstat_ent *mdstat_read(int hold, int start);
 extern void free_mdstat(struct mdstat_ent *ms);
 extern void mdstat_wait(int seconds);
 
@@ -186,7 +200,7 @@ extern struct superswitch {
 	void (*getinfo_super)(struct mdinfo *info, mddev_ident_t ident, void *sbv);
 	int (*update_super)(struct mdinfo *info, void *sbv, char *update, char *devname, int verbose);
 	__u64 (*event_super)(void *sbv);
-	int (*init_super)(struct supertype *st, void **sbp, mdu_array_info_t *info, char *name);
+	int (*init_super)(struct supertype *st, void **sbp, mdu_array_info_t *info, unsigned long long size, char *name);
 	void (*add_to_super)(void *sbv, mdu_disk_info_t *dinfo);
 	int (*store_super)(struct supertype *st, int fd, void *sbv);
 	int (*write_init_super)(struct supertype *st, void *sbv, mdu_disk_info_t *dinfo, char *devname);
@@ -211,6 +225,10 @@ struct supertype {
 extern struct supertype *super_by_version(int vers, int minor);
 extern struct supertype *guess_super(int fd);
 
+#if __GNUC__ < 3
+struct stat64;
+#endif
+
 #ifdef UCLIBC
   struct FTW {};
 # define FTW_PHYS 1
@@ -232,7 +250,7 @@ extern int Manage_reconfig(char *devname, int fd, int layout);
 extern int Manage_subdevs(char *devname, int fd,
 			  mddev_dev_t devlist, int verbose);
 extern int Grow_Add_device(char *devname, int fd, char *newdev);
-extern int Grow_addbitmap(char *devname, int fd, char *file, int chunk, int delay, int write_behind);
+extern int Grow_addbitmap(char *devname, int fd, char *file, int chunk, int delay, int write_behind, int force);
 
 
 extern int Assemble(struct supertype *st, char *mddev, int mdfd,
@@ -250,7 +268,7 @@ extern int Build(char *mddev, int mdfd, int chunk, int level, int layout,
 
 
 extern int Create(struct supertype *st, char *mddev, int mdfd,
-		  int chunk, int level, int layout, unsigned long size, int raiddisks, int sparedisks,
+		  int chunk, int level, int layout, unsigned long long size, int raiddisks, int sparedisks,
 		  char *name,
 		  int subdevs, mddev_dev_t devlist,
 		  int runstop, int verbose, int force, int assume_clean,
@@ -301,6 +319,7 @@ extern unsigned long calc_csum(void *super, int bytes);
 extern int enough(int level, int raid_disks, int layout,
 		   char *avail, int avail_disks);
 extern int ask(char *mesg);
+extern unsigned long long get_component_size(int fd);
 
 
 extern char *human_size(long long bytes);
